@@ -12,7 +12,7 @@ import re
 import os
 
 
-WordFilePath = os.path.join("docs", 'wd.txt')
+WordFilePath = os.path.join("lib/hx_txt/", 'wd.txt')
 
 
 class NaiveFilter():
